@@ -1,8 +1,9 @@
 class NonceOracle:
 
-    def __init__(self, address):
+    def __init__(self, address, confirmed=True):
         self.address = address
         self.nonce = self.get_nonce()
+        self.confirmed = confirmed
 
 
     def get_nonce(self):
