@@ -12,12 +12,12 @@ class SrcItem(enum.Enum):
 
 class Src:
 
-    def __init__(self, src=None):
+    def __init__(self, src=None, dialect_filter=None):
         self.__src = None
         self.__hash = None
         self.__wire = None
         if src != None:
-            self.apply_src(src)
+            self.apply_src(src, dialect_filter=dialect_filter)
 
 
     @classmethod
@@ -29,8 +29,10 @@ class Src:
         return v
 
 
-    def apply_src(self, src):
+    def apply_src(self, src, dialect_filter=None):
         src = self.src_normalize(src)
+        if dialect_filter != None:
+            src = dialect_filter.apply_src(src)
         self.__src = self.src_validate(src)
         return self.__src
 
@@ -86,3 +88,9 @@ class Src:
 
     def __repr__(self):
         return self.__src
+
+
+    def load_src(self, dialect_filter=None):
+        raise NotImplementedError()
+
+
